pub(crate) fn validate_digits(code: &[u8]) -> Result<(), FormatError>Expand description
Validate that every byte of code is an ASCII digit '0'..='9'.
Errors
Returns FormatError::NonDigit at the position of the first non-digit
byte.
pub(crate) fn validate_digits(code: &[u8]) -> Result<(), FormatError>Validate that every byte of code is an ASCII digit '0'..='9'.
Returns FormatError::NonDigit at the position of the first non-digit
byte.